@@ -1,7 +1,6 @@
 /*
-  $Id: freebsd.h,v 1.10 2008/05/11 09:50:54 rocky Exp $
-
-  Copyright (C) 2003, 2004, 2008 Rocky Bernstein <rocky@gnu.org>
+  Copyright (C) 2003, 2004, 2008, 2010, 2012
+  Rocky Bernstein <rocky@gnu.org>
 
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -26,6 +25,10 @@
 # include "config.h"
 #endif
 
+#ifdef HAVE_STDBOOL_H
+# include <stdbool.h>
+#endif 
+
 #include <cdio/sector.h>
 #include "cdio_assert.h"
 #include "cdio_private.h"
@@ -115,7 +118,9 @@ struct ioc_read_audio
 typedef  enum {
   _AM_NONE,
   _AM_IOCTL,
-  _AM_CAM
+  _AM_CAM,
+  _AM_MMC_RDWR,
+  _AM_MMC_RDWR_EXCL,
 } access_mode_t;
 
 typedef struct {
@@ -213,7 +218,7 @@ bool read_toc_freebsd_ioctl (_img_private_t *env);
 
   Return 0 if no error.
  */
-int run_mmc_cmd_freebsd_cam( const void *p_user_data, 
+int run_mmc_cmd_freebsd_cam( void *p_user_data, 
 			     unsigned int i_timeout_ms,
 			     unsigned int i_cdb, 
 			     const mmc_cdb_t *p_cdb, 
@@ -229,4 +234,12 @@ lsn_t get_disc_last_lsn_freebsd_ioctl (_img_private_t *_obj);
 bool init_freebsd_cam (_img_private_t *env);
 void free_freebsd_cam (void *user_data);
 
+/** Try to obtain SCSI address tuple of path.
+    @return  1 is success , 0 is failure
+*/
+int obtain_scsi_adr_freebsd_cam(char *path, 
+                                int *bus_no, int *host_no, int *channel_no,
+                                int *target_no, int *lun_no);
+
+
 #endif /*HAVE_FREEBSD_CDROM*/
